@@ -31,7 +31,7 @@
 #include "kpToolEllipticalSelection.h"
 
 #include <klocale.h>
-#include <kdebug.h>
+#include "kpLogCategories.h"
 
 #include "document/kpDocument.h"
 #include "layers/selections/image/kpEllipticalImageSelection.h"
@@ -63,7 +63,7 @@ bool kpToolEllipticalSelection::drawCreateMoreSelectionAndUpdateStatusBar (
     if (!dragAccepted && accidentalDragAdjustedPoint == startPoint ())
     {
     #if DEBUG_KP_TOOL_ELLIPTICAL_SELECTION && 1
-        kDebug () << "\tnon-text NOP - return";
+        qCDebug(kpLogTools) << "\tnon-text NOP - return";
     #endif
         setUserShapePoints (accidentalDragAdjustedPoint);
         return false;
