@@ -34,7 +34,7 @@
 #include "commands/imagelib/effects/kpEffectBalanceCommand.h"
 #include "pixmapfx/kpPixmapFX.h"
 
-#include <kdebug.h>
+#include "kpLogCategories.h"
 #include <klocale.h>
 #include <knuminput.h>
 
